Crate lru_disk_cache

Crate lru_disk_cache 

Re-exports

pub use crate::lru_cache::LruCache;
pub use crate::lru_cache::Meter;

Modules

lru_cache
A cache that holds a limited number of key-value pairs. When the capacity of the cache is exceeded, the least-recently-used (where “used” means a look-up or putting the pair into the cache) pair is automatically removed.

Structs

LruDiskCache
An LRU cache of files on disk.

Enums

Error
Errors returned by this crate.

Traits

ReadSeek
Trait objects can’t be bounded by more than one non-builtin trait.

Type Aliases

Result
A convenience Result type