Crate lru_disk_cache
lru_
disk_
cache
0.4.1
All Items
Crate Items
Re-exports
Modules
Structs
Enums
Traits
Type Aliases
Crate
lru_
disk_
cache
Re-exports

pub use crate::lru_cache::
LruCache
;
pub use crate::lru_cache::
Meter
;
Modules

lru_
cache
A cache that holds a limited number of key-value pairs. When the capacity of the cache is exceeded, the least-recently-used (where “used” means a look-up or putting the pair into the cache) pair is automatically removed.
Structs

LruDisk
Cache
An LRU cache of files on disk.
Enums

Error
Errors returned by this crate.
Traits

Read
Seek
Trait objects can’t be bounded by more than one non-builtin trait.
Type Aliases

Result
A convenience
Result
type